package examples.decorator.java;

/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http://www.mozilla.org/MPL/ or http://aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.pattern.
 *
 * Contributor(s):   
 */
 
/**
 * Defines the <i>Decorator</i> interface. This is an abstract class to allow
 * for default implementations (set varible "output", provide default 
 * implementation for <code>print(String)</code>.
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 06/13/02
 */  
                       
public abstract class OutputDecorator implements Output {

    /**
     * the <code>Output</code> to decorate
     */  

	protected Output output;
	
    /**
     * Prints the argument string to <code>System.out</code>. This method is
     * overwritten by concrete decorators. The default implementation 
     *
     * @param s the string to be printed.
     */
      
	public void print(String s) { 
		output.print(s);
	}
	
    /**
     * Defines the constructor signature. Also provides a default 
     * implementation so that concrete decorators don't have to 
     * re-implement can just call <code>super(..)</code> and don't have
     * to deal with setting the variable themselves.
     *
     * @param output the component to decorate.
     */
 
 	public OutputDecorator(Output output) {
		this.output = output;
	}
}